pub struct ArgsFormatter<'a> { /* private fields */ }Trait Implementations
Sourceimpl FormatIns for ArgsFormatter<'_>
impl FormatIns for ArgsFormatter<'_>
fn options(&self) -> &Options
fn write_ins(&mut self, ins: &Ins) -> Result
fn write_space(&mut self) -> Result
fn write_separator(&mut self) -> Result
Sourcefn write_uimm(&mut self, uimm: u32) -> Result
fn write_uimm(&mut self, uimm: u32) -> Result
Unsigned immediate
Sourcefn write_simm(&mut self, simm: i32) -> Result
fn write_simm(&mut self, simm: i32) -> Result
Signed immediate
Sourcefn write_branch_target(&mut self, branch_target: BranchTarget) -> Result
fn write_branch_target(&mut self, branch_target: BranchTarget) -> Result
The direct destination address of a branch instruction
Sourcefn write_status_reg(&mut self, status_reg: StatusReg) -> Result
fn write_status_reg(&mut self, status_reg: StatusReg) -> Result
Status register
Sourcefn write_status_fields(&mut self, status_fields: StatusFields) -> Result
fn write_status_fields(&mut self, status_fields: StatusFields) -> Result
Status register with field masks
Sourcefn write_shift_op(&mut self, shift_op: ShiftOp) -> Result
fn write_shift_op(&mut self, shift_op: ShiftOp) -> Result
Shift operation
Sourcefn write_coproc(&mut self, coproc: Coproc) -> Result
fn write_coproc(&mut self, coproc: Coproc) -> Result
Coprocessor
Sourcefn write_co_reg(&mut self, co_reg: CoReg) -> Result
fn write_co_reg(&mut self, co_reg: CoReg) -> Result
Coprocessor register
Sourcefn write_aif_flags(&mut self, aif_flags: AifFlags) -> Result
fn write_aif_flags(&mut self, aif_flags: AifFlags) -> Result
In a CPS instruction, specifies which interrupt bits to enable or disable
Sourcefn write_endianness(&mut self, endianness: Endianness) -> Result
fn write_endianness(&mut self, endianness: Endianness) -> Result
Used by SETEND, specifies the endianness for data accesses
Sourcefn write_sreg(&mut self, sreg: Sreg) -> Result
fn write_sreg(&mut self, sreg: Sreg) -> Result
General-purpose register for single-precision floating-point numbers
Sourcefn write_dreg(&mut self, dreg: Dreg) -> Result
fn write_dreg(&mut self, dreg: Dreg) -> Result
General-purpose register for double-precision floating-point numbers
Sourcefn write_fpscr(&mut self, fpscr: Fpscr) -> Result
fn write_fpscr(&mut self, fpscr: Fpscr) -> Result
Floating-Point Status and Control Register
Sourcefn write_addr_ldr_str(&mut self, addr_ldr_str: AddrLdrStr) -> Result
fn write_addr_ldr_str(&mut self, addr_ldr_str: AddrLdrStr) -> Result
The memory address of an LDR(B)/STR(B)/PLD instruction
Sourcefn write_s(&mut self, s: bool) -> Result<(), Error>
fn write_s(&mut self, s: bool) -> Result<(), Error>
Mnemonic suffix, updates status flags when present
Sourcefn write_l(&mut self, l: bool) -> Result<(), Error>
fn write_l(&mut self, l: bool) -> Result<(), Error>
Mnemonic suffix, specifies a long load/store for LDC/STC instructions
Sourcefn write_wb(&mut self, wb: bool) -> Result<(), Error>
fn write_wb(&mut self, wb: bool) -> Result<(), Error>
In LDM/STM, write the last accessed address back to the base register
Sourcefn write_user_mode(&mut self, user_mode: bool) -> Result<(), Error>
fn write_user_mode(&mut self, user_mode: bool) -> Result<(), Error>
In LDM/STM, access user mode registers while in a privileged mode
Sourcefn write_subtract(&mut self, subtract: bool) -> Result<(), Error>
fn write_subtract(&mut self, subtract: bool) -> Result<(), Error>
In LDR/STR and similar, subtract the index register from the base register
Sourcefn write_blx_target(&mut self, blx_target: BlxTarget) -> Result<(), Error>
fn write_blx_target(&mut self, blx_target: BlxTarget) -> Result<(), Error>
The destination of a BLX instruction, which can be direct (immediate) or indirect (register)
Sourcefn write_cond(&mut self, cond: Cond) -> Result<(), Error>
fn write_cond(&mut self, cond: Cond) -> Result<(), Error>
Mnemonic suffix, specifies the condition for whether to execute the instruction
Sourcefn write_reg_list(&mut self, reg_list: RegList) -> Result<(), Error>
fn write_reg_list(&mut self, reg_list: RegList) -> Result<(), Error>
List of general-purpose registers, used by LDM/STM
Sourcefn write_msr_op2(&mut self, msr_op2: MsrOp2) -> Result<(), Error>
fn write_msr_op2(&mut self, msr_op2: MsrOp2) -> Result<(), Error>
Second operand of the MSR instruction, can be an immediate or a register
Sourcefn write_op2(&mut self, op2: Op2) -> Result<(), Error>
fn write_op2(&mut self, op2: Op2) -> Result<(), Error>
Second operand of a data-processing operation, can be an immediate, an immediate-shifted register or a register-shifted register.
Sourcefn write_shift_reg(&mut self, shift_reg: ShiftReg) -> Result<(), Error>
fn write_shift_reg(&mut self, shift_reg: ShiftReg) -> Result<(), Error>
Register shifted by another register
Sourcefn write_shift_imm(&mut self, shift_imm: ShiftImm) -> Result<(), Error>
fn write_shift_imm(&mut self, shift_imm: ShiftImm) -> Result<(), Error>
Register shifted by an immediate
Sourcefn write_op2_shift(&mut self, op2_shift: Op2Shift) -> Result<(), Error>
fn write_op2_shift(&mut self, op2_shift: Op2Shift) -> Result<(), Error>
Second operand of a shift instruction, can be an immediate or a register
Sourcefn write_cps_effect(&mut self, cps_effect: CpsEffect) -> Result<(), Error>
fn write_cps_effect(&mut self, cps_effect: CpsEffect) -> Result<(), Error>
Mnemonic suffix for CPS, specifies whether to enable/disable interrupt bits or just set the processor mode
Sourcefn write_addr_ldc_stc(&mut self, addr_ldc_stc: AddrLdcStc) -> Result<(), Error>
fn write_addr_ldc_stc(&mut self, addr_ldc_stc: AddrLdcStc) -> Result<(), Error>
The memory address of an LDC/STC instruction
Sourcefn write_ldm_stm_mode(&mut self, ldm_stm_mode: LdmStmMode) -> Result<(), Error>
fn write_ldm_stm_mode(&mut self, ldm_stm_mode: LdmStmMode) -> Result<(), Error>
Mnemonic suffix for LDM/STM, specifies how to step the base address
Sourcefn write_addr_ldr_str_post(
&mut self,
addr_ldr_str_post: AddrLdrStrPost,
) -> Result<(), Error>
fn write_addr_ldr_str_post( &mut self, addr_ldr_str_post: AddrLdrStrPost, ) -> Result<(), Error>
A post-indexed memory address for LDR(B)(T)/STR(B)(T)
Sourcefn write_ldr_str_offset(
&mut self,
ldr_str_offset: LdrStrOffset,
) -> Result<(), Error>
fn write_ldr_str_offset( &mut self, ldr_str_offset: LdrStrOffset, ) -> Result<(), Error>
The offset value in the memory address of a LDR(B)/STR(B) instruction, can be an immediate or a register
Sourcefn write_addr_misc_load(
&mut self,
addr_misc_load: AddrMiscLoad,
) -> Result<(), Error>
fn write_addr_misc_load( &mut self, addr_misc_load: AddrMiscLoad, ) -> Result<(), Error>
The memory address of a miscellaneous load/store instruction
Sourcefn write_misc_load_offset(
&mut self,
misc_load_offset: MiscLoadOffset,
) -> Result<(), Error>
fn write_misc_load_offset( &mut self, misc_load_offset: MiscLoadOffset, ) -> Result<(), Error>
The offset value in the memory address of a miscellaneous load/store instruction, can be an immediate or a register
Sourcefn write_srs_rfe_mode(&mut self, srs_rfe_mode: SrsRfeMode) -> Result<(), Error>
fn write_srs_rfe_mode(&mut self, srs_rfe_mode: SrsRfeMode) -> Result<(), Error>
Mnemonic suffix for SRS/RFE, specifies how to step the stack pointer
Sourcefn write_reg_side(&mut self, reg_side: RegSide) -> Result<(), Error>
fn write_reg_side(&mut self, reg_side: RegSide) -> Result<(), Error>
Mnemonic suffix, specifies which half of a register to use as an operand
Sourcefn write_swap_rm(&mut self, swap_rm: bool) -> Result<(), Error>
fn write_swap_rm(&mut self, swap_rm: bool) -> Result<(), Error>
Mnemonic suffix, when performing two 16x16 bit multiplications, swap the two halfwords of Rm
Sourcefn write_round(&mut self, round: bool) -> Result<(), Error>
fn write_round(&mut self, round: bool) -> Result<(), Error>
Mnemonic suffix, round the multiplication result instead of truncating
Sourcefn write_round_zero(&mut self, round_zero: bool) -> Result<(), Error>
fn write_round_zero(&mut self, round_zero: bool) -> Result<(), Error>
Mnemonic suffix, when converting a floating-point number to an integer, round the result towards zero
Sourcefn write_nan_exc(&mut self, nan_exc: bool) -> Result<(), Error>
fn write_nan_exc(&mut self, nan_exc: bool) -> Result<(), Error>
Mnemonic suffix, specifies that a comparison operation should cause an exception if any operand is NaN
Sourcefn write_vcmp_f32_op2(&mut self, vcmp_f32_op2: VcmpF32Op2) -> Result<(), Error>
fn write_vcmp_f32_op2(&mut self, vcmp_f32_op2: VcmpF32Op2) -> Result<(), Error>
Second operand of a VCMP.F32 instruction, can be zero or a register
Sourcefn write_vcmp_f64_op2(&mut self, vcmp_f64_op2: VcmpF64Op2) -> Result<(), Error>
fn write_vcmp_f64_op2(&mut self, vcmp_f64_op2: VcmpF64Op2) -> Result<(), Error>
Second operand of a VCMP.F64 instruction, can be zero or a register
Sourcefn write_sreg_list(&mut self, sreg_list: SregList) -> Result<(), Error>
fn write_sreg_list(&mut self, sreg_list: SregList) -> Result<(), Error>
List of general-purpose single-precision floation-point registers, used by VLDM/VSTM
Sourcefn write_dreg_list(&mut self, dreg_list: DregList) -> Result<(), Error>
fn write_dreg_list(&mut self, dreg_list: DregList) -> Result<(), Error>
List of general-purpose double-precision floation-point registers, used by VLDM/VSTM
Sourcefn write_dreg_index(&mut self, dreg_index: DregIndex) -> Result<(), Error>
fn write_dreg_index(&mut self, dreg_index: DregIndex) -> Result<(), Error>
A double-precision floating-point register and index (0 or 1) to move to/from
Sourcefn write_vldm_vstm_mode(
&mut self,
vldm_vstm_mode: VldmVstmMode,
) -> Result<(), Error>
fn write_vldm_vstm_mode( &mut self, vldm_vstm_mode: VldmVstmMode, ) -> Result<(), Error>
Mnemonic suffix for VLDM/VSTM, specifies how to step the base address