pub struct DiffSection {
pub name: String,
pub kind: i32,
pub size: u64,
pub address: u64,
pub match_percent: Option<f32>,
pub data_diff: Vec<DiffDataSegment>,
pub reloc_diff: Vec<DiffDataRelocation>,
}Expand description
Diff information for a section
Fields
name: Stringkind: i32size: u64address: u64match_percent: Option<f32>data_diff: Vec<DiffDataSegment>reloc_diff: Vec<DiffDataRelocation>Implementations
Sourceimpl DiffSection
impl DiffSection
Sourcepub fn kind(&self) -> DiffSectionKind
pub fn kind(&self) -> DiffSectionKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: DiffSectionKind)
pub fn set_kind(&mut self, value: DiffSectionKind)
Sets kind to the provided enum value.
Sourcepub fn match_percent(&self) -> f32
pub fn match_percent(&self) -> f32
Returns the value of match_percent, or the default value if match_percent is unset.
Sourceimpl DiffSection
impl DiffSection
pub fn new(obj: &Object, section: &Section, section_diff: &SectionDiff) -> Self