pub struct DiffSymbol {
pub name: String,
pub demangled_name: Option<String>,
pub address: u64,
pub size: u64,
pub flags: Option<DiffSymbolFlags>,
pub kind: i32,
pub target_symbol: Option<u32>,
pub match_percent: Option<f32>,
pub instructions: Vec<DiffInstructionRow>,
pub data_diff: Vec<DiffDataSegment>,
}Expand description
Symbol with diff information
Fields
name: Stringdemangled_name: Option<String>address: u64size: u64flags: Option<DiffSymbolFlags>kind: i32target_symbol: Option<u32>The symbol index in the other object that this symbol was diffed against
match_percent: Option<f32>instructions: Vec<DiffInstructionRow>Instruction diff rows (for code symbols)
data_diff: Vec<DiffDataSegment>Data diff (for data symbols)
Implementations
Sourceimpl DiffSymbol
impl DiffSymbol
Sourcepub fn demangled_name(&self) -> &str
pub fn demangled_name(&self) -> &str
Returns the value of demangled_name, or the default value if demangled_name is unset.
Sourcepub fn target_symbol(&self) -> u32
pub fn target_symbol(&self) -> u32
Returns the value of target_symbol, or the default value if target_symbol is unset.
Sourcepub fn match_percent(&self) -> f32
pub fn match_percent(&self) -> f32
Returns the value of match_percent, or the default value if match_percent is unset.
Sourcepub fn kind(&self) -> DiffSymbolKind
pub fn kind(&self) -> DiffSymbolKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: DiffSymbolKind)
pub fn set_kind(&mut self, value: DiffSymbolKind)
Sets kind to the provided enum value.
Sourceimpl DiffSymbol
impl DiffSymbol
pub fn new( obj: &Object, symbol_idx: usize, symbol: &Symbol, symbol_diff: &SymbolDiff, diff_config: &DiffObjConfig, ) -> Result<Self>