pub struct Measures {Show 16 fields
pub fuzzy_match_percent: f32,
pub total_code: u64,
pub matched_code: u64,
pub matched_code_percent: f32,
pub total_data: u64,
pub matched_data: u64,
pub matched_data_percent: f32,
pub total_functions: u32,
pub matched_functions: u32,
pub matched_functions_percent: f32,
pub complete_code: u64,
pub complete_code_percent: f32,
pub complete_data: u64,
pub complete_data_percent: f32,
pub total_units: u32,
pub complete_units: u32,
}Expand description
Progress info for a report or unit
Fields
fuzzy_match_percent: f32Overall match percent, including partially matched functions and data
total_code: u64Total size of code in bytes
matched_code: u64Fully matched code size in bytes
matched_code_percent: f32Fully matched code percent
total_data: u64Total size of data in bytes
matched_data: u64Fully matched data size in bytes
matched_data_percent: f32Fully matched data percent
total_functions: u32Total number of functions
matched_functions: u32Fully matched functions
matched_functions_percent: f32Fully matched functions percent
complete_code: u64Completed (or “linked”) code size in bytes
complete_code_percent: f32Completed (or “linked”) code percent
complete_data: u64Completed (or “linked”) data size in bytes
complete_data_percent: f32Completed (or “linked”) data percent
total_units: u32Total number of units
complete_units: u32Completed (or “linked”) units
Implementations
Sourceimpl Measures
impl Measures
Sourcepub fn calc_fuzzy_match_percent(&mut self)
pub fn calc_fuzzy_match_percent(&mut self)
Average the fuzzy match percentage over total code bytes.
Sourcepub fn calc_matched_percent(&mut self)
pub fn calc_matched_percent(&mut self)
Calculate the percentage of matched code, data, and functions.