pub struct Report {
pub measures: Option<Measures>,
pub units: Vec<ReportUnit>,
pub version: u32,
pub categories: Vec<ReportCategory>,
}Expand description
Project progress report
Fields
measures: Option<Measures>Overall progress info
units: Vec<ReportUnit>Units within this report
version: u32Report version
categories: Vec<ReportCategory>Progress categories
Implementations
Sourceimpl Report
impl Report
Sourcepub fn parse(data: &[u8]) -> Result<Self>
pub fn parse(data: &[u8]) -> Result<Self>
Attempts to parse the report as binary protobuf or JSON.
Sourcepub fn migrate(&mut self) -> Result<()>
pub fn migrate(&mut self) -> Result<()>
Migrates the report to the latest version. Fails if the report version is newer than supported.
Sourcepub fn calculate_progress_categories(&mut self)
pub fn calculate_progress_categories(&mut self)
Calculate progress categories based on unit metadata.