pub struct ReportUnitMetadata {
pub complete: Option<bool>,
pub module_name: Option<String>,
pub module_id: Option<u32>,
pub source_path: Option<String>,
pub progress_categories: Vec<String>,
pub auto_generated: Option<bool>,
}Expand description
Extra metadata for a unit
Fields
complete: Option<bool>Whether this unit is marked as complete (or “linked”)
module_name: Option<String>The name of the module this unit belongs to
module_id: Option<u32>The ID of the module this unit belongs to
source_path: Option<String>The path to the source file of this unit
progress_categories: Vec<String>Progress categories for this unit
auto_generated: Option<bool>Whether this unit is automatically generated (not user-provided)
Implementations
Sourceimpl ReportUnitMetadata
impl ReportUnitMetadata
Sourcepub fn complete(&self) -> bool
pub fn complete(&self) -> bool
Returns the value of complete, or the default value if complete is unset.
Sourcepub fn module_name(&self) -> &str
pub fn module_name(&self) -> &str
Returns the value of module_name, or the default value if module_name is unset.
Sourcepub fn module_id(&self) -> u32
pub fn module_id(&self) -> u32
Returns the value of module_id, or the default value if module_id is unset.
Sourcepub fn source_path(&self) -> &str
pub fn source_path(&self) -> &str
Returns the value of source_path, or the default value if source_path is unset.
Sourcepub fn auto_generated(&self) -> bool
pub fn auto_generated(&self) -> bool
Returns the value of auto_generated, or the default value if auto_generated is unset.