Module data

Module data 

Constants

BYTES_PER_ROW

Functions

diff_bss_section
Compare the addresses and sizes of each symbol in the BSS sections.
diff_bss_symbol
diff_data_section
Compare the data sections of two object files.
diff_data_symbol
diff_generic_section
Compares a section of two object files. This essentially adds up the match percentage of each symbol in the section.
no_diff_bss_section
no_diff_data_section
no_diff_data_symbol
resolve_relocation
symbol_name_matches