pub enum ConfigPropertyId {
Show 23 variants
FunctionRelocDiffs,
Demangler,
AnalyzeDataFlow,
ShowDataFlow,
SpaceBetweenArgs,
ShowSymbolSizes,
CombineDataSections,
CombineTextSections,
PreferredStringEncoding,
ArmArchVersion,
ArmVfpV2,
ArmUnifiedSyntax,
ArmAvRegisters,
ArmR9Usage,
ArmSlUsage,
ArmFpUsage,
ArmIpUsage,
MipsAbi,
MipsInstrCategory,
MipsRegisterPrefix,
MipsProdgSnAsInvertedRegs,
PpcCalculatePoolRelocations,
X86Formatter,
}Variants
FunctionRelocDiffs
Function relocation diffs
How relocation targets will be diffed in the function view.
Demangler
Demangler
Which demangler should be used to demangle each symbol.
AnalyzeDataFlow
(Experimental) Perform data flow analysis
Use data flow analysis to display known information about register contents where possible
ShowDataFlow
Show data flow
Show data flow analysis results in place of register name where present
SpaceBetweenArgs
Space between args
Adds a space between arguments in the diff output.
ShowSymbolSizes
Show symbol sizes
Shows symbol sizes in the symbol view.
CombineDataSections
Combine data sections
Combines data sections with equal names.
CombineTextSections
Combine text sections
Combines all text sections into one.
PreferredStringEncoding
Preferred string encoding
Which encoding to use when diffing string literals used in functions.
ArmArchVersion
Architecture version
ARM architecture version to use for disassembly.
ArmVfpV2
VFPv2 instructions
Adds floating-point instructions from VFPv2.
ArmUnifiedSyntax
Unified syntax
Disassemble as unified assembly language (UAL).
ArmAvRegisters
Use A/V registers
Display R0-R3 as A1-A4 and R4-R11 as V1-V8.
ArmR9Usage
Display R9 as
ArmSlUsage
Display R10 as SL
Used for explicit stack limits.
ArmFpUsage
Display R11 as FP
Used for frame pointers.
ArmIpUsage
Display R12 as IP
Used for interworking and long branches.
MipsAbi
ABI
MIPS ABI to use for disassembly.
MipsInstrCategory
Instruction category
MIPS instruction category to use for disassembly.
MipsRegisterPrefix
Register ‘$’ prefix
Display MIPS register names with a ‘$’ prefix.
MipsProdgSnAsInvertedRegs
ProDG SN AS VU register order
Changes the register order for specific R5900EE instructions to match the syntax used by the SN AS from ProDG (-snas flag).
PpcCalculatePoolRelocations
Calculate pooled data references
Display pooled data references in functions as fake relocations.
X86Formatter
Format
x86 disassembly syntax.
Implementations
Sourceimpl ConfigPropertyId
impl ConfigPropertyId
pub fn kind(&self) -> ConfigPropertyKind