pub struct DiffObjConfig {Show 23 fields
pub function_reloc_diffs: FunctionRelocDiffs,
pub demangler: Demangler,
pub analyze_data_flow: bool,
pub show_data_flow: bool,
pub space_between_args: bool,
pub show_symbol_sizes: ShowSymbolSizes,
pub combine_data_sections: bool,
pub combine_text_sections: bool,
pub preferred_string_encoding: PreferredStringEncoding,
pub arm_arch_version: ArmArchVersion,
pub arm_vfp_v2: bool,
pub arm_unified_syntax: bool,
pub arm_av_registers: bool,
pub arm_r9_usage: ArmR9Usage,
pub arm_sl_usage: bool,
pub arm_fp_usage: bool,
pub arm_ip_usage: bool,
pub mips_abi: MipsAbi,
pub mips_instr_category: MipsInstrCategory,
pub mips_register_prefix: bool,
pub mips_prodg_sn_as_inverted_regs: bool,
pub ppc_calculate_pool_relocations: bool,
pub x86_formatter: X86Formatter,
}Fields
function_reloc_diffs: FunctionRelocDiffsFunction relocation diffs
How relocation targets will be diffed in the function view.
demangler: DemanglerDemangler
Which demangler should be used to demangle each symbol.
analyze_data_flow: bool(Experimental) Perform data flow analysis
Use data flow analysis to display known information about register contents where possible
show_data_flow: boolShow data flow
Show data flow analysis results in place of register name where present
space_between_args: boolSpace between args
Adds a space between arguments in the diff output.
show_symbol_sizes: ShowSymbolSizesShow symbol sizes
Shows symbol sizes in the symbol view.
combine_data_sections: boolCombine data sections
Combines data sections with equal names.
combine_text_sections: boolCombine text sections
Combines all text sections into one.
preferred_string_encoding: PreferredStringEncodingPreferred string encoding
Which encoding to use when diffing string literals used in functions.
arm_arch_version: ArmArchVersionArchitecture version
ARM architecture version to use for disassembly.
arm_vfp_v2: boolVFPv2 instructions
Adds floating-point instructions from VFPv2.
arm_unified_syntax: boolUnified syntax
Disassemble as unified assembly language (UAL).
arm_av_registers: boolUse A/V registers
Display R0-R3 as A1-A4 and R4-R11 as V1-V8.
arm_r9_usage: ArmR9UsageDisplay R9 as
arm_sl_usage: boolDisplay R10 as SL
Used for explicit stack limits.
arm_fp_usage: boolDisplay R11 as FP
Used for frame pointers.
arm_ip_usage: boolDisplay R12 as IP
Used for interworking and long branches.
mips_abi: MipsAbiABI
MIPS ABI to use for disassembly.
mips_instr_category: MipsInstrCategoryInstruction category
MIPS instruction category to use for disassembly.
mips_register_prefix: boolRegister ‘$’ prefix
Display MIPS register names with a ‘$’ prefix.
mips_prodg_sn_as_inverted_regs: boolProDG SN AS VU register order
Changes the register order for specific R5900EE instructions to match the syntax used by the SN AS from ProDG (-snas flag).
ppc_calculate_pool_relocations: boolCalculate pooled data references
Display pooled data references in functions as fake relocations.
x86_formatter: X86FormatterFormat
x86 disassembly syntax.
Implementations
Sourceimpl DiffObjConfig
impl DiffObjConfig
pub fn get_property_value(&self, id: ConfigPropertyId) -> ConfigPropertyValue
pub fn set_property_value( &mut self, id: ConfigPropertyId, value: ConfigPropertyValue, ) -> Result<(), ()>
pub fn set_property_value_str( &mut self, id: ConfigPropertyId, value: &str, ) -> Result<(), ()>