pub struct JobQueue {
pub jobs: Vec<JobState>,
pub results: Vec<JobResult>,
}Fields
jobs: Vec<JobState>results: Vec<JobResult>Implementations
Sourceimpl JobQueue
impl JobQueue
Sourcepub fn push_once(&mut self, job: Job, func: impl FnOnce() -> JobState)
pub fn push_once(&mut self, job: Job, func: impl FnOnce() -> JobState)
Adds a job to the queue if a job of the given kind is not already running.
Sourcepub fn is_running(&self, kind: Job) -> bool
pub fn is_running(&self, kind: Job) -> bool
Returns whether a job of the given kind is running.
Sourcepub fn any_running(&self) -> bool
pub fn any_running(&self) -> bool
Returns whether any job is running.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = &mut JobState> + '_
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut JobState> + '_
Iterates over all jobs mutably.
Sourcepub fn iter_finished(
&mut self,
) -> impl Iterator<Item = (&mut JobState, Result<JobResult>)> + '_
pub fn iter_finished( &mut self, ) -> impl Iterator<Item = (&mut JobState, Result<JobResult>)> + '_
Iterates over all finished jobs, returning the job state and the result.
Sourcepub fn clear_finished(&mut self)
pub fn clear_finished(&mut self)
Clears all finished jobs.
Sourcepub fn clear_errored(&mut self)
pub fn clear_errored(&mut self)
Clears all errored jobs.
Sourcepub fn collect_results(&mut self)
pub fn collect_results(&mut self)
Collects the results of all finished jobs and handles any errors.