Module split_meta

Module split_meta 

Structs

SplitMeta
This is used to store metadata about the source of an object file, such as the original virtual addresses and the tool that wrote it.

Constants

ELF_NOTE_SPLIT
SHT_SPLITMETA
SPLITMETA_SECTION