Constants
Functions
- diff_
bss_ section - Compare the addresses and sizes of each symbol in the BSS sections.
- diff_
bss_ symbol - diff_
data_ section - Compare the data sections of two object files.
- diff_
data_ symbol - diff_
generic_ section - Compares a section of two object files. This essentially adds up the match percentage of each symbol in the section.
- no_
diff_ bss_ section - no_
diff_ data_ section - no_
diff_ data_ symbol - resolve_
relocation - symbol_
name_ matches